# coding: utf-8

"""
    Pieces Isomorphic OpenAPI

    Endpoints for Assets, Formats, Users, Asset, Format, User.

    The version of the OpenAPI document: 1.0
    Contact: tsavo@pieces.app
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class ExternallySourcedEnum(str, Enum):
    """
    This is an enum that will highlight something that is externally sourced.
    """

    """
    allowed enum values
    """
    TWITTER = 'TWITTER'
    MEDIUM = 'MEDIUM'
    LINKED_IN = 'LINKED_IN'
    INSTAGRAM = 'INSTAGRAM'
    FACEBOOK = 'FACEBOOK'
    REDDIT = 'REDDIT'
    DISCORD = 'DISCORD'
    BIT_BUCKET = 'BIT_BUCKET'
    GIT_LAB = 'GIT_LAB'
    GIT_HUB = 'GIT_HUB'
    SLACK = 'SLACK'
    MAILGUN = 'MAILGUN'

    @classmethod
    def from_json(cls, json_str: str) -> ExternallySourcedEnum:
        """Create an instance of ExternallySourcedEnum from a JSON string"""
        return ExternallySourcedEnum(json.loads(json_str))


