# coding: utf-8

"""
    Pieces Isomorphic OpenAPI

    Endpoints for Assets, Formats, Users, Asset, Format, User.

    The version of the OpenAPI document: 1.0
    Contact: tsavo@pieces.app
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class PlatformEnum(str, Enum):
    """
    This is an Enumeration for a Platform ie, WEB, MACOS, LINUX, WINDOWS
    """

    """
    allowed enum values
    """
    WEB = 'WEB'
    MACOS = 'MACOS'
    LINUX = 'LINUX'
    WINDOWS = 'WINDOWS'
    FUCHSIA = 'FUCHSIA'
    IOS = 'IOS'
    ANDROID = 'ANDROID'
    UNKNOWN = 'UNKNOWN'

    @classmethod
    def from_json(cls, json_str: str) -> PlatformEnum:
        """Create an instance of PlatformEnum from a JSON string"""
        return PlatformEnum(json.loads(json_str))


